@@ -1,6 +1,7 @@
 import socket, urllib3, json
 global debug
 debug = "off"
+protected = " Protected by: He1Zen, v1.0"
 
 class server:
     def send(region:str, email:str, *message:str):
@@ -13,25 +14,43 @@ class server:
         http = urllib3.PoolManager()
         request = http.request('GET', url)
         data = json.loads(request.data.decode('utf8'))
-        if debug == "on":
-            print("[40%] URL json data decode")
         ip = str(data["mailip"])
         port = int(data["mailport"])
+        request = http.request('GET', "https://api.ipify.org/")
+        my_ip = request.data.decode('utf8')
+        if debug == "on":
+            print("[40%] URL json data decode")
         if debug == "on":
             print("[60%] Server IP "+ip+":"+str(port))
+            print("[65%] My IP: "+my_ip)
+            print("[70%] Checking IP on blacklist")
         message = " ".join([str(m) for m in message])
-        client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        client.connect((ip, port))
-        if debug == "on":
-            print("[80%] Server connected!")
-        client.sendall(bytes("smtp|"+region+"|"+email+"|"+message,'UTF-8'))
-        if debug == "on":
-            print("[98%] Data send to server")
-        code = client.recv(4096)
-        code = code.decode('utf-8')
-        client.shutdown(socket.SHUT_RDWR)
-        client.close()
-        return code
+        check = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        check.connect((ip, port))
+        check.sendall(bytes("free|check|ip|"+my_ip,'UTF-8'))
+        code = check.recv(4096)
+        get = code.decode('utf-8')
+        check.shutdown(socket.SHUT_RDWR)
+        check.close()
+        if get == "blacklisted":
+            return "Access denied, you ip address blacklisted!"+protected
+        elif get == "tor":
+            return "Access denied, please disable tor!"+protected
+        elif get == "vpn" or get == "proxy":
+            return "Access denied, please disable vpn!"+protected
+        else:
+            client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            client.connect((ip, port))
+            if debug == "on":
+                print("[80%] Server connected!")
+            client.sendall(bytes("smtp|"+region+"|"+email+"|"+message,'UTF-8'))
+            if debug == "on":
+                print("[98%] Data send to server")
+            code = client.recv(4096)
+            code = code.decode('utf-8')
+            client.shutdown(socket.SHUT_RDWR)
+            client.close()
+            return code
     def mail():
         if debug == "on":
             print("[7%] Debug mode ON")
@@ -76,7 +95,7 @@ class server:
         client.close()
         return check
     def regions():
-        return "SMTP regions: tr, ru, ua, us, uk, de, fr, it"
+        return "SMTP regions: us, uk, de, ua, ru, tr"
     def debug(type:str):
         global debug
         if type == "on":
